cordova.define("com.twc.cordova.video.VideoPlayer", function(require, exports, module) {
var exec = require('cordova/exec');

var videoplayer = {
        //event logic
        _events: {},
        addListener: function(eventName, callback) {
            var events = this._events,
                callbacks = events[eventName] = events[eventName] || [];
            callbacks.push(callback);
        },
        raiseEvent: function(eventName, args) {
            console.log("raiseEvent '"+eventName+"' args '"+args+"'");
            var callbacks = this._events[eventName] || [];
            for (var i = 0, l = callbacks.length; i < l; i++) {
                callbacks[i].apply(null, args);
            }
        },
        removeListeners : function(){
            this._events = {};
        },

        /**
         * Opens and prepares the player component

         supported mime-types

         "application/vnd.ms-sstr+xml";
         "application/dash+xml";
         "application/vnd.apple.mpegurl";
         "video/mp4";
         "video/m4a";
         "audio/mpeg";
         "video/MP2T";
         "audio/aac";
         "video/webm";

         drmObject
         {
             type : "playready",
             licenseUri : "",
             customData : ""
         }
         */

        open:function(url, mime, drmObject) {
            exec(null, null, "VideoPlayer", "open", [url,mime,drmObject]);
        },

        /**
         * Resumes and prepares the player component (no reset on the player config)

         supported mime-types

         "application/vnd.ms-sstr+xml";
         "application/dash+xml";
         "application/vnd.apple.mpegurl";
         "video/mp4";
         "video/m4a";
         "audio/mpeg";
         "video/MP2T";
         "audio/aac";
         "video/webm";

         drmObject
         {
             type : "playready",
             licenseUri : "",
             customData : ""
         }
         */

        resume:function(url, mime, drmObject) {
            exec(null, null, "VideoPlayer", "resume", [url,mime,drmObject]);
        },

        /**
         * Relases the player
         */
        close:function(){
            exec(null, null, "VideoPlayer", "close", []);
        },

        /**
         * Sets autoplay: true for autoplay, false don't autoplay
         */
        setAutoPlay:function(autoplay){
            var auto = autoplay? 1 : 0;
            exec(null, null, "VideoPlayer", "setAutoPlay", [auto]);
        },

        /**
         * Calls play on the player with an optional time (miliseconds) to seekTo
         */
        play:function(time) {
            exec(null, null, "VideoPlayer", "play", [time]);
        },

        /**
         * toggles the pause state of the media
         */
        togglePause:function(){
            exec(null, null, "VideoPlayer", "togglePause", []);
        },

        /**
         * Calls seekTo on the player. Resumes playback if player was playing
         */
        seekTo:function(time){
            exec(null, null, "VideoPlayer", "seekTo", [time]);
        },

        /**
         * Returns the current time of the content being played (or -1)
         */
        getCurrentTime: function(callback){
            exec(callback, null, "VideoPlayer", "getCurrentTime", []);
        },

        /**
         * Returns the duration of the content (or -1)
         */
        getDuration: function(callback){
            exec(callback, null, "VideoPlayer", "getDuration", []);
        },

        /**
         * Gets a String reprensentation of the state
         */
        getState:function(callback){
            exec(callback, null, "VideoPlayer", "getState", []);
        },

        /**
         * Gets the playing state
         */
        isPlaying:function(callback){
            exec(callback, null, "VideoPlayer", "isPlaying", []);
        },

        /**
         * Gets the mime-type
         */
        getMime:function(callback){
            exec(callback, null, "VideoPlayer", "getMime", []);
        },

        /**
         * Pauses playback
         */
        pause: function(){
            exec(null, null, "VideoPlayer", "pause", []);
        },

        /**
         * Stops playback
         */
        stop: function(){
            exec(null, null, "VideoPlayer", "stop", []);
        },

        /**
         * Sets the draw rectangle of the player using a RELATIVE system.
         The system takes 4 numbers, representing the values of the left, top, right and bottom positions.
         These values are ranged from -1 to 1, creating a relative cartesian plane coordinate system.

         fullscreen (-1,1,1,-1)

         1
         |
         |
         |
         -1 ------0-------1
         |
         |
         |
         -1


         *
         */
        setRectangle: function(l,t,r,b){
            exec(null, null, "VideoPlayer", "setRectangle", [l,t,r,b]);
        },

        /**
         * Gets the original size of the video as a String (ie. '1920x1080')
         */
        getVideoSize: function(callback){
            exec(callback, null, "VideoPlayer", "getVideoSize", []);
        },

        /**
         * Aspect ratio indication.
         * "full" will stretch the video to fit the rectangle set in setPlayerRectangle.
         * "original" will keep the original aspect ratio of the video and add black bars in the remaining areas in the rectangle set in setPlayerRectangle.
         */
        setAspectRatio:function(indication){
            exec(null, null, "VideoPlayer", "setAspectRatio", [indication]);
        },

        /**
         * Skip forward x amount of miliseconds(default time 5000)
         */
        skipForward:function(miliseconds){
            exec(null, null, "VideoPlayer", "skipForward", [miliseconds]);
        },

        /**
         * Skip backwards x amount of miliseconds(default time 5000)
         */
        skipBackward:function(miliseconds){
            exec(null, null, "VideoPlayer", "skipBackward", [miliseconds]);
        },

        /**
         * Loop state, 1 to activate, 0 to deactivate
         */
        setLoop:function(loop){
            exec(null, null, "VideoPlayer", "setLoop", [loop]);
        },

        /**
         * Returns a list of the currently available audio tracks, in the format
         *   Array[{String id, int index]
    */
        allAudioTracks:function(callback){
            exec(callback, null, "VideoPlayer", "allAudioTracks", []);
        },

        /**
         * Set the selected audio track
         */
        setAudioTrack:function(id, index){
            exec(null, null, "VideoPlayer", "setAudioTrack", [id, index]);
        },

        /**
         * Return the selected audio track
         *
         * {id : String, index : int}
         */
        getAudioTrack:function(callback){
            exec(callback, null, "VideoPlayer", "getAudioTrack", []);
        },

        /**
         * Returns an Array of the available subtitles
         *
         * return Array[String language int index]
         */
        allSubtitleTracks:function(callback){
            exec(callback, null, "VideoPlayer", "allSubtitleTracks", []);
        },

        /**
         * sets the external captions
         *
         * params : textTracks (Array) — list of subtitle objects using the format {id:"", url:""}
         */
        setExternalSubtitles:function(textTracks){
            var jsonEncoded = JSON.stringify(textTracks);
            exec(null, null, "VideoPlayer", "setExternalSubtitles", [jsonEncoded]);
        },

        /**
         * Return the selected subtitle track
         *
         * {id : String, index : int}
         */
        getSubtitleTrack:function(callback){
            exec(callback, null, "VideoPlayer", "getSubtitleTrack", []);
        },

        /**
         * set the selected subtitle track
         */
        setSubtitleTrack:function(language, index){
            exec(null, null, "VideoPlayer", "setSubtitleTrack", [language, index]);
        },

        /**
         * get the selected subtitle track enabled state
         */
        getSubtitleActive:function(callback){
            exec(callback, null, "VideoPlayer", "getSubtitleActive", []);
        },

        /**
         * enable selected subtitle track
         */
        setSubtitleActive:function(active){
            exec(null, null, "VideoPlayer", "setSubtitleActive", [active]);
        },

        /**
         * change subtitle color
         */
        setSubtitleColor:function(hexColor){
            exec(null, null, "VideoPlayer", "setSubtitleColor", [hexColor]);
        },

       /**
         * get current bitrate
         */
        getCurrentBitrate: function(callback){
            exec(callback, null, "VideoPlayer", "getCurrentBitrate", []);
        },

        /**
         * Tests if the device's screen is UHD
         */
        isUHD:function(callback){
            exec(callback, null, "VideoPlayer", "isUHD", []);
        },

        /**
         * Tests if the device's screen is HDR color mode compatible
         */
        isHDR:function(callback){
            exec(callback, null, "VideoPlayer", "isHDR", []);
        }

    };

    module.exports = videoplayer;

});
